summaryrefslogtreecommitdiff
path: root/internal/fsm/fsm.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/fsm/fsm.go')
-rw-r--r--internal/fsm/fsm.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/internal/fsm/fsm.go b/internal/fsm/fsm.go
index b8fd644..c3c7efa 100644
--- a/internal/fsm/fsm.go
+++ b/internal/fsm/fsm.go
@@ -106,8 +106,8 @@ func (fsm *FSM) HasTransition(check FSMStateID) bool {
return false
}
-// getGraphFilename gets the full path to the graph filename including the .graph extension
-func (fsm *FSM) getGraphFilename(extension string) string {
+// graphFilename gets the full path to the graph filename including the .graph extension
+func (fsm *FSM) graphFilename(extension string) string {
debugPath := path.Join(fsm.Directory, "graph")
return fmt.Sprintf("%s%s", debugPath, extension)
}
@@ -115,8 +115,8 @@ func (fsm *FSM) getGraphFilename(extension string) string {
// writeGraph writes the state machine to a .graph file
func (fsm *FSM) writeGraph() {
graph := fsm.GenerateGraph()
- graphFile := fsm.getGraphFilename(".graph")
- graphImgFile := fsm.getGraphFilename(".png")
+ graphFile := fsm.graphFilename(".graph")
+ graphImgFile := fsm.graphFilename(".png")
f, err := os.Create(graphFile)
if err != nil {
return